@@ -51,6 +51,10 @@ OC.L10N.register(
     "You do not have permission to create a file at the specified location" : "Немате дозволу да креирате фајл на наведеној локацији",
     "The file could not be converted." : "Фајл није могао да се конвертује.",
     "Could not get relative path to converted file" : "Није могла да се преузме релативна путања до конвертованог фајла",
+    "Limit must be a positive integer." : "Граница мора бити позитиван цео број.",
+    "The replacement character may only be a single character." : "Карактер замене мора бити само један карактер.",
+    "Filename sanitization already started." : "Пречишћавање имена фајла је већ започето.",
+    "No filename sanitization in progress." : "Није у току ниједно пречишћавање имена фајла.",
     "Favorite files" : "Омиљени фајлови",
     "No favorites" : "Нема омиљених",
     "More favorites" : "Још омиљених",
@@ -68,18 +72,13 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Пренос власништва {path} на корисника {user} завршен.",
     "in %s" : "за %s",
     "Transferred from %1$s on %2$s" : "Пренесено са %1$s на %2$s",
-    "Files compatibility" : "Компатибилност фајлова",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Дозвољава се ограничавање имена фајлова тако да сви клијенти могу да их синхронизују. Подразумевано се дозвољавају сва имена фајлова која су исправна на POSIX системима (нпр. Linux или macOS).",
-    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Када се укључе Windows компатибилна имена фајлова, постојећи фајлови се више неће моћи мењати, али њихов власник може да им промени име на исправно ново име.",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Фајлови такође могу аутоматски да се мигрирају након укључивања овог подешавања, молимо вас да погледате документацију у вези са occ командом.",
-    "Enforce Windows compatibility" : "Форсирај Windows компатибилност",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Ово ће да блокира имена фајлова која су неисправна на Windows системима, као што су она која користе резервисана имена или специјалне карактере. Али ово неће форсирати компатибилност разликовања малих и великих слова.",
     "File Management" : "Управљање фајловима",
     "Home" : "Почетна",
     "Target folder does not exist any more" : "Одредишна фасцикла више не постоји",
     "Reload current directory" : "Поново учитај текући директоријум",
     "Go to the \"{dir}\" directory" : "Иди у „{dir}” дирекотријум",
     "Current directory path" : "Путања текућег директоријума",
+    "Share" : "Пдели",
     "Your have used your space quota and cannot upload files anymore" : "Искористили сте квоту простора и више не можете да отпремате фајлове",
     "You do not have permission to upload or create files here." : "Немате дозволу да овде отпремите или креирате фајлове.",
     "Drag and drop files here to upload" : "Да отпремите, превуците и отпустите фајлове овде",
@@ -94,7 +93,6 @@ OC.L10N.register(
     "This node is unavailable" : "Овај чвор није доступан",
     "Another entry with the same name already exists." : "Већ постоји ставка са истим именом.",
     "Invalid filename." : "Неисправно име фајла.",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "„{oldName}” је промењено на „{newName}”",
     "Rename file" : "Промени назив фајла",
     "Folder" : "Фасцикла",
     "Unknown file type" : "Непознат тип фајла",
@@ -104,18 +102,65 @@ OC.L10N.register(
     "{ext} text" : "{ext} текст",
     "Pending" : "На чекању",
     "Unknown date" : "Непознат датум",
-    "Clear filter" : "Очисти филтер",
-    "Modified" : "Измењен",
-    "Search everywhere" : "Претражи свуда",
-    "Type" : "Тип",
     "Active filters" : "Активни филтери",
     "Remove filter" : "Уклони филтер",
+    "Today" : "Данас",
+    "Last 7 days" : "Последњих 7 дана",
+    "Last 30 days" : "Последњих 30 дана",
+    "This year ({year})" : "Ове године ({year})",
+    "Last year ({year})" : "Прошле године ({year})",
+    "Custom date range" : "Произвољни опсег датума",
+    "Search everywhere" : "Претражи свуда",
+    "Documents" : "Документи",
+    "Spreadsheets" : "Табеле",
+    "Presentations" : "Презентације",
+    "PDFs" : "PDF фајлови",
+    "Folders" : "Фолдери",
+    "Audio" : "Звук",
+    "Images" : "Слике",
+    "Videos" : "Видео снимци",
+    "Filters" : "Филтери",
+    "Appearance" : "Изглед",
+    "Show hidden files" : "Прикажи скривене фајлове",
+    "Show file type column" : "Прикажи колону са типом фајла",
+    "Show file extensions" : "Прикажи екстензије фајла",
+    "Crop image previews" : "Опсецање прегледа слика",
+    "General" : "Опште",
+    "Sort favorites first" : "Сортирај прво омиљене",
+    "Sort folders before files" : "Поређај фолдере испред фајлова",
+    "Default view" : "Подразумевани поглед",
+    "All files" : "Сви фајлови",
+    "Personal files" : "Лични фајлови",
+    "Additional settings" : "Додатне поставке",
+    "Actions" : "Радње",
+    "File actions" : "Фајл акције",
+    "Selection" : "Избор",
+    "Select all files" : "Изабери све фајлове",
+    "Deselect all" : "Поништи цео избор",
+    "Select or deselect" : "Изабери или уклони избор",
+    "Select a range" : "Изабери опсег",
+    "Navigation" : "Навигација",
+    "Go to parent folder" : "Иди на фолдер родитељ",
+    "Go to file above" : "Иди на фајл изнад",
+    "Go to file below" : "Иди на фајл испод",
+    "Go left in grid" : "Иди на лево у мрежи",
+    "Go right in grid" : "Иди на десно у мреж",
+    "View" : "Погледај",
+    "Toggle grid view" : "Укључи/искључи приказ мреже",
+    "Show those shortcuts" : "Прикажи те пречице",
+    "Warnings" : "Упозорења",
+    "Warn before changing a file extension" : "Упозори пре измене екстензије фајла",
+    "WebDAV URL" : "WebDAV URL",
+    "How to access files using WebDAV" : "Како да приступите фајловима преко WebDAV протокола",
     "Total rows summary" : "Резиме укупног броја редова",
     "Toggle selection for all files and folders" : "Укљ./искљ. избор за све фајлове и фолдере",
     "Name" : "Назив",
     "File type" : "Тип фајла",
     "Size" : "Величина",
-    "Actions" : "Радње",
+    "Modified" : "Измењен",
+    "{displayName}: failed on some elements" : "{displayName}: није успело на неким елементима",
+    "{displayName}: done" : "{displayName}: завршено",
+    "{displayName}: failed" : "{displayName}: није успело",
     "(selected)" : "(изабрано)",
     "List of files and folders." : "Листа фајлова и фолдера.",
     "You have used your space quota and cannot upload files anymore." : "Искористили сте квоту простора и више не можете да отпремате фајлове.",
@@ -123,7 +168,12 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Ова листа није у потпуности приказана из разлога перформанси. Фајлови ће се приказивати како се крећете кроз листу.",
     "File not found" : "Фајл није нађен",
     "_{count} selected_::_{count} selected_" : ["изабран је {count}","изабрана су {count}","изабрано је {count}"],
+    "Views" : "Прикази",
+    "Search everywhere …" : "Претражи свуда …",
+    "Search here …" : "Претражи овде …",
     "Search scope options" : "Опције опсега претраге",
+    "Search here" : "Претражи овде",
+    "Owner" : "Власник",
     "{usedQuotaByte} used" : "{usedQuotaByte} искоришћено",
     "{used} of {quota} used" : "{used} од {quota} искоришћено",
     "{relative}% used" : "{relative}% искоришћено",
@@ -135,8 +185,27 @@ OC.L10N.register(
     "Create new folder" : "Направи нову фасциклу",
     "This name is already in use." : "Ово име се већ користи.",
     "Create" : "Направи",
+    "Files starting with a dot are hidden by default" : "Фајлови који почињу тачком су подразумевано скривени",
+    "Failed to start filename sanitization." : "Није успело покретање пречишћавање имена фајла.",
+    "Failed to refresh filename sanitization status." : "Није успело освежавање статуса пречишћавања имена фајла.",
+    "Filename sanitization in progress." : "Пречишћавање имена фајла је у току.",
+    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Тренутно је већ обрађено {processedUsers} од {totalUsers} налога.",
+    "Preparing …" : "Припрема се …",
+    "Refresh" : "Освежи",
+    "All files have been santized for Windows filename support." : "Пречишћени су сви фајлови тако да подржавају Windows захтеве за име фајла.",
+    "Some files could not be sanitized, please check your logs." : "Неки фајлови нису могли да се пречисте, молимо вас да погледате дневнике.",
+    "Sanitization errors" : "Грешке пречишћавања",
+    "Not sanitized filenames" : "Имена фајлова који нису пречишћени",
+    "Windows filename support has been enabled." : "Укључена је подршка за Windows имена фајлова.",
+    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Мада ово спречава да корисници креирају нове фајлове са именима која се не подржавају, постојећим фајловима још увек није промењено име, тако да још увек могу да покваре синхронизацију на Windows систему.",
+    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Можете да окинете промену имена фајлова који имају неисправно име, то ће се обавити у позадини и потрајаће неко време.",
+    "Please note that this may cause high workload on the sync clients." : "Имајте на уму да ово може изазвати велико радно оптерећење на клијентима за синхронизацију.",
+    "Limit" : "Граница",
+    "This allows to configure how many users should be processed in one background job run." : "Ово вам омогућава да подесите број корисника који ће се обрадити у једном позадинском послу.",
+    "Sanitize filenames" : "Пречисти имена фајлова",
+    "(starting)" : "(почиње)",
     "Fill template fields" : "Попуните поља шаблона",
-    "Submitting fields …" : "Поља се подносе…",
+    "Submitting fields …" : "Поља се подносе …",
     "Submit" : "Пошаљи",
     "Choose a file or folder to transfer" : "Одаберите фајл или фасциклу за пренос",
     "Transfer" : "Пренеси",
@@ -158,11 +227,11 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "Ако уклоните екстензију „{old}” фајл може да постане нечитљив.",
     "Adding the file extension \"{new}\" may render the file unreadable." : "Ако додате екстензију „{new}” фајл може да постане нечитљив.",
     "Do not show this dialog again." : "Не приказуј поново овај дијалог.",
+    "Cancel" : "Поништи",
+    "Rename" : "Преименуј",
     "Select file or folder to link to" : "Изаберите фајл или фолдер на који показује линк",
     "Choose {file}" : "Изабери {file}",
-    "Share" : "Пдели",
-    "Shared by link" : "Дељени путем везе",
-    "Shared" : "Подељено",
+    "Files settings" : "Подешавања фајлова",
     "Switch to list view" : "Пређи на поглед листе",
     "Switch to grid view" : "Пређи на поглед мреже",
     "The file could not be found" : "Фајл није могао да се пронађе",
@@ -177,69 +246,39 @@ OC.L10N.register(
     "No files in here" : "Овде нема фајлова",
     "Upload some content or sync with your devices!" : "Отпремите неки садржај или синхронизујте са вашим уређајима!",
     "Go back" : "Иди назад",
-    "Views" : "Прикази",
-    "Files settings" : "Подешавања фајлова",
+    "Loading …" : "Учитава се…",
     "Your files" : "Ваши фајлови",
     "Open in files" : "Отвори у фајловима",
     "File cannot be accessed" : "Фајлу не може да се приступи",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Фајл није могао да се пронађе или немате дозволу да га прегледате. Замолите пошиљаоца да га подели.",
     "No search results for “{query}”" : "Није нађен ниједан резултат за „{query}”",
     "Search for files" : "Претражи фајлове",
-    "Clipboard is not available" : "Клипборд није доступан",
-    "General" : "Опште",
-    "Default view" : "Подразумевани поглед",
-    "All files" : "Сви фајлови",
-    "Personal files" : "Лични фајлови",
-    "Sort favorites first" : "Сортирај прво омиљене",
-    "Sort folders before files" : "Поређај фолдере испред фајлова",
-    "Appearance" : "Изглед",
-    "Show hidden files" : "Прикажи скривене фајлове",
-    "Show file type column" : "Прикажи колону са типом фајла",
-    "Crop image previews" : "Опсецање прегледа слика",
-    "Additional settings" : "Додатне поставке",
-    "WebDAV" : "ВебДАВ",
-    "WebDAV URL" : "WebDAV URL",
-    "Copy" : "Копирај",
-    "Warnings" : "Упозорења",
-    "Keyboard shortcuts" : "Пречице на тастатури",
-    "File actions" : "Фајл акције",
-    "Rename" : "Преименуј",
-    "Delete" : "Обриши",
-    "Manage tags" : "Управљање ознакама",
-    "Selection" : "Избор",
-    "Select all files" : "Изабери све фајлове",
-    "Deselect all" : "Поништи цео избор",
-    "Navigation" : "Навигација",
-    "View" : "Погледај",
-    "Toggle grid view" : "Укључи/искључи приказ мреже",
-    "Show those shortcuts" : "Прикажи те пречице",
-    "You" : "Ви",
-    "Shared multiple times with different people" : "Дељено више пута са разним људима",
-    "Unable to change the favorite state of the file" : "Није успела измена стања омиљено за фајл",
-    "Error while loading the file data" : "Грешка при учитавању података фајла",
-    "Owner" : "Власник",
-    "Remove from favorites" : "Избаци из омиљених",
-    "Add to favorites" : "Додај у омиљене",
-    "Tags" : "Ознаке",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Дозвољава се ограничавање имена фајлова тако да сви клијенти могу да их синхронизују. Подразумевано се дозвољавају сва имена фајлова која су исправна на POSIX системима (нпр. Linux или macOS).",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Када се укључе Windows компатибилна имена фајлова, постојећи фајлови се више неће моћи мењати, али њихов власник може да им промени име на исправно ново име.",
+    "Failed to toggle Windows filename support" : "Није успело укљ./искљ. подршке за Windows имена фајлова",
+    "Files compatibility" : "Компатибилност фајлова",
+    "Enforce Windows compatibility" : "Форсирај Windows компатибилност",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Ово ће да блокира имена фајлова која су неисправна на Windows системима, као што су она која користе резервисана имена или специјалне карактере. Али ово неће форсирати компатибилност разликовања малих и великих слова.",
     "Blank" : "Празно",
     "Unable to create new file from template" : "Из шаблона није могао да се креира нови фајл",
     "Pick a template for {name}" : "Изаберите шаблон за {name}",
     "Create a new file with the selected template" : "Креирање новог фајла по изабраном шаблону",
     "Creating file" : "Креирање фајла",
     "Save as {displayName}" : "Сачувај као {displayName}",
-    "Save as …" : "Сачувај као",
-    "Converting files …" : "Фајлови се конвертују",
+    "Save as …" : "Сачувај као …",
+    "Converting files …" : "Фајлови се конвертују …",
     "Failed to convert files: {message}" : "Није успела конверзија фајлова: {message}",
     "All files failed to be converted" : "Ниједан фајл није могао да се конвертује",
     "One file could not be converted: {message}" : "Један фајл није могао да се конвертује: {message}",
-    "_One file could not be converted_::_%n files could not be converted_" : ["Један фајл није могао да се конвертује","Није могло да се конвертује %n фајла","Није могло да се конвертује %n фајлова"],
-    "_One file successfully converted_::_%n files successfully converted_" : ["Фајл је успешно конвертован","Успешно су конвертована %n фајла","Успешно је конвертовано %n фајлова"],
-    "Files successfully converted" : "Фајлови су успешно конвертовани",
+    "_%n file could not be converted_::_%n files could not be converted_" : [" %n фајл није могао да се конвертује"," %n фајла нису могла да се конвертују"," %n фајлова није могло да се конвертује"],
+    "_%n file converted_::_%n files converted_" : ["конветован је %n фајл","конветована су %n фајла","конветовано је %n фајлова"],
+    "Files converted" : "Конвертовано фајлова",
     "Failed to convert files" : "Није успела конверзија фајлова",
-    "Converting file …" : "Фајл се конвертује",
+    "Converting file …" : "Фајл се конвертује …",
     "File successfully converted" : "Фајл је успешно конвертован",
     "Failed to convert file: {message}" : "Није успела конверзија фајла: {message}",
     "Failed to convert file" : "Фајл није могао да се конвертује",
+    "Delete" : "Обриши",
     "Leave this share" : "Напусти ово дељење",
     "Leave these shares" : "Напусти ова дељења",
     "Disconnect storage" : "Искључи складиште",
@@ -253,24 +292,28 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Управо ћете неповратно обрисати {count} ставку","Управо ћете неповратно обрисати {count} ставке","Управо ћете неповратно обрисати {count} ставки"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Управо ћете обрисати {count} ставку","Управо ћете обрисати {count} ставке","Управо ћете обрисати {count} ставки"],
     "Confirm deletion" : "Потврди брисање",
-    "Cancel" : "Поништи",
     "Download" : "Преузми",
-    "Moving \"{source}\" to \"{destination}\" …" : "„{source}” се премешта у „{destination}”…",
-    "Copying \"{source}\" to \"{destination}\" …" : "„{source}” се копира у „{destination}”…",
+    "The requested file is not available." : "Тражени фајл није доступан.",
+    "The requested files are not available." : "Тражени фајлови нису доступни.",
+    "Add to favorites" : "Додај у омиљене",
+    "Remove from favorites" : "Избаци из омиљених",
+    "Add or remove favorite" : "Додај или уклони омиљене",
+    "Move" : "Помери",
+    "Copy" : "Копирај",
+    "Move or copy" : "Помери или копирај",
     "Destination is not a folder" : "Одредиште није фолдер",
     "This file/folder is already in that directory" : "Овај фајл/фолдер се већ налази у том директоријуму",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Фајл/фолдер не можете да преместите у самог себе или у његов подфолдер",
-    "(copy)" : "(копиран)",
-    "(copy %n)" : "(копирано %n)",
     "A file or folder with that name already exists in this folder" : "У овом фолдеру већ постоји фајл или фолдер са тим именом",
     "The files are locked" : "Фајлови су закључани",
     "The file does not exist anymore" : "Фајл више не постоји",
+    "Moving \"{source}\" to \"{destination}\" …" : "„{source}” се премешта у „{destination}” …",
+    "Copying \"{source}\" to \"{destination}\" …" : "„{source}” се копира у „{destination}” …",
     "Choose destination" : "Изаберите одредиште",
     "Copy to {target}" : "Копирај у {target}",
     "Move to {target}" : "Премести у {target}",
-    "Move" : "Помери",
     "Move or copy operation failed" : "Није успела операција премештања или копирања",
-    "Move or copy" : "Помери или копирај",
+    "Open folder" : "Отвори фасциклу",
     "Open folder {displayName}" : "Отвори фолдер {displayName}",
     "Open in Files" : "Отвори у Фајловима",
     "Open locally" : "Отвори локално",
@@ -280,26 +323,16 @@ OC.L10N.register(
     "Retry and close" : "Покушај поново и затвори",
     "Open online" : "Отвори на мрежи",
     "Details" : "Детаљи",
+    "Unfavorite" : "Није омиљено",
     "View in folder" : "Види у фасцикли",
-    "Today" : "Данас",
-    "Last 7 days" : "Последњих 7 дана",
-    "Last 30 days" : "Последњих 30 дана",
-    "This year ({year})" : "Ове године ({year})",
-    "Last year ({year})" : "Прошле године ({year})",
-    "Documents" : "Документи",
-    "Spreadsheets" : "Табеле",
-    "Presentations" : "Презентације",
-    "PDFs" : "PDF фајлови",
-    "Folders" : "Фолдери",
-    "Audio" : "Звук",
-    "Images" : "Слике",
-    "Videos" : "Видео снимци",
+    "Type" : "Тип",
     "Created new folder \"{name}\"" : "Креиран је нови фолдер „{name}”",
     "Unable to initialize the templates directory" : "Фолдер са шаблонима није могао да се иницијализује",
     "Create templates folder" : "Креирај фолдер шаблона",
     "Templates" : "Шаблони",
     "New template folder" : "Нови фолдер шаблона",
     "In folder" : "У фолдеру",
+    "Search in all files" : "Претражи у свим фајловима",
     "Search in folder: {folder}" : "Претрага у фолдеру: {folder}",
     "One of the dropped files could not be processed" : "Један од упуштених фајлова не може да се обради",
     "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Ваш интернет прегледач не подржава Filesystem API. Нећете моћи да отпремате директоријуме",
@@ -308,16 +341,17 @@ OC.L10N.register(
     "Some files could not be uploaded" : "Неки фајлови нису могли да се отпреме",
     "Files uploaded successfully" : "Фајлови су успешно отремљени",
     "No files to process" : "Нема фајлова за обраду",
-    "Some files could not be copied" : "Неки фајлови нису могли да се копирају",
-    "Some files could not be moved" : "Неке фајлове нисам могао да преместим",
     "Files copied successfully" : "Фајлови су успешно копирани",
     "Files moved successfully" : "Фајлови су успешно премештени",
+    "Some files could not be copied" : "Неки фајлови нису могли да се копирају",
+    "Some files could not be moved" : "Неке фајлове нисам могао да преместим",
     "Conflicts resolution skipped" : "Прексочено је разрешавање конфилката",
     "Upload cancelled" : "Отпремање је отказано",
     "Could not rename \"{oldName}\", it does not exist any more" : "Не може да се промени име фајла „{oldName}” јер фајл више не постоји",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Назив „{newName}” се већ користи у директоријуму „{dir}”. Молимо вас да изаберете неко друго име.",
     "Could not rename \"{oldName}\"" : "Не може да се промени име фајла „{oldName}”",
     "This operation is forbidden" : "Ова радња је забрањена",
+    "This folder is unavailable, please try again later or contact the administration" : "Овај фолдер није доступан, молимо вас да покушате касније или да контактирате администрацију",
     "Storage is temporarily not available" : "Складиште привремено није  доступно",
     "Unexpected error: {error}" : "Неочекивана грешка: {error}",
     "_%n file_::_%n files_" : ["%n фајл","%n фајла","%n фајлова"],
@@ -332,6 +366,7 @@ OC.L10N.register(
     "No favorites yet" : "Још нема омиљених",
     "Files and folders you mark as favorite will show up here" : "Фајлови и фасцикле које обележите као омиљене појавиће се овде",
     "List of your files and folders." : "Листа ваших фајлова и фолдера.",
+    "Folder tree" : "Стабло фолдера",
     "List of your files and folders that are not shared." : "Листа ваших фајлова и фолдера који се не деле.",
     "No personal files found" : "Није пронађен ниједан лични фајл",
     "Files that are not shared will show up here." : "Овде ће се појавити фајлови који се не деле.",
@@ -345,118 +380,32 @@ OC.L10N.register(
     "Select all" : "Означи све",
     "Upload too large" : "Отпремање је превелико",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Фајлови које желите да отпремите превазилазе ограничење отпремања на овом серверу.",
-    "File could not be found" : "Фајл није нађен",
-    "Show list view" : "Prikaži prikaz liste",
-    "Show grid view" : "Prikaži prikaz mreže",
-    "Close" : "Затвори",
-    "Could not create folder \"{dir}\"" : "Не могу да направим фасциклу „{dir}“",
-    "This will stop your current uploads." : "Ово ће да прекине тренутна отпремања.",
-    "Upload cancelled." : "Отпремање је отказано.",
-    "Processing files …" : "Обрађујем фајлове…",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Не могу да отпремим {filename} јер је то или директоријум или има 0 бајтова",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Нема простора. Отпремате {size1} али само {size2} је преостало",
-    "Target folder \"{dir}\" does not exist any more" : "Одредишна фасцикла „{dir}“ више не постоји",
-    "An unknown error has occurred" : "Десила се непозната грешка",
-    "File could not be uploaded" : "Фајл не може да се отпреми",
-    "Uploading …" : "Отпремам…",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Отпремање … ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} од {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Отпремање те ставке није подржано",
-    "Error when assembling chunks, status code {status}" : "Грешки при прикупљању делова фајла, статус код {status}",
-    "Choose target folder" : "Одаберите одредишну фасциклу",
-    "Set reminder" : "Постави подсетник",
-    "Edit locally" : "Уреди локално",
-    "Open" : "Отвори",
-    "Could not load info for file \"{file}\"" : "Не могу да учитам информације фајла „{file}“",
-    "Please select tag(s) to add to the selection" : "Молимо вас да изаберете ознаку (или више њих) која треба да се дода избору",
-    "Apply tag(s) to selection" : "Примени ознаку (или више њих) на избор",
-    "Select directory \"{dirName}\"" : "Избор директоријума „{dirName}",
-    "Select file \"{fileName}\"" : "Избор фајла „{fileName}”",
-    "Unable to determine date" : "Не могу да одредим датум",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Овај директоријум није доступан, проверите дневник или контактирајте администратора",
-    "Could not move \"{file}\", target exists" : "Не могу да преместим „{file}“. Одредиште већ постоји",
-    "Could not move \"{file}\"" : "Не могу да преместим „{file}“",
-    "copy" : "копиран",
-    "Could not copy \"{file}\", target exists" : "Не могу да копирам „{file}“, одредиште већ постоји",
-    "Could not copy \"{file}\"" : "Не могу да копирам „{file}“",
-    "Copied {origin} inside {destination}" : "Копиран {origin} у {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Копиран{origin} и још {nbfiles} других фајлова у {destination}",
-    "{newName} already exists" : "{newName} већ постоји",
-    "Could not create file \"{file}\"" : "Не могу да направим фајл „{file}“",
-    "Could not create file \"{file}\" because it already exists" : "Не могу да направим фајл „{file}“ јер већ постоји",
-    "Could not create folder \"{dir}\" because it already exists" : "Не могу да направим фасциклу „{dir}“ јер већ постоји",
-    "Could not fetch file details \"{file}\"" : "Не могу да дохватим детаље за „{file}“",
-    "Error deleting file \"{fileName}\"." : "Грешка при брисању фајла „{fileName}“.",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Нема резултата претраге у осталим фасциклама за {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Унесите више од два карактера да претражујете у другим фасциклама",
-    "{dirs} and {files}" : "{dirs} и {files}",
-    "_including %n hidden_::_including %n hidden_" : ["укључујући и %n скривени","укључујући и %n скривена","укључујући и %n скривених"],
-    "You do not have permission to upload or create files here" : "Немате дозволу да овде отпремите или креирате фајлове",
-    "_Uploading %n file_::_Uploading %n files_" : ["Отпремам %n фајл","Отпремам %n фајла","Отпремам %n фајлова"],
-    "New" : "Нов",
-    "New file/folder menu" : "Мени за нови фајл/фолдер",
-    "Select file range" : "Одаберите опсег фајлова",
-    "{used}%" : "{used}%",
-    "{used} used" : "{used} искоришћено",
-    "\"{name}\" is an invalid file name." : "„{name}“ није исправан назив фајла.",
-    "File name cannot be empty." : "Назив фајла не може бити празан.",
-    "\"/\" is not allowed inside a file name." : "„/“ није дозвољен каракетер у имену фајла.",
-    "\"{name}\" is not an allowed filetype" : "„{name}“ није дозвољени тип фајла",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Складиште власника {owner} је пуно, више није могуће отпремање или синхронизација фајлова!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Групни фолдер „{mountPoint}” је пун, фајлови више не могу да се ажурирају или синхронизују!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Спаљно складиште „{mountPoint}” је пуно, фајлови више не могу да се ажурирају или синхронизују!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Ваше складиште је пуно, фајлови випе не могу да се ажурирају или синхронизују!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Складиште корисника {owner} је скоро пуно ({usedSpacePercent}%).",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Групна фасцикла „{mountPoint}“ је скоро пуна ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Спољашње складиште „{mountPoint}“ је скоро пуно ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Ваше складиште је скоро пуно ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["се подудара са „{filter}”","се подударају са „{filter}","се подудара са „{filter}"],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Копиран је директан линк (функционише само за особе који имају приступ овом фајлу/фолдеру)",
-    "Path" : "Путања",
-    "_%n byte_::_%n bytes_" : ["%n бајт","%n бајта","%n бајтова"],
-    "Favored" : "Наклоњен",
-    "Favor" : "Наклоност",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Копирај директни линк (ради само за особе које имају приступ овом фајлу/фолдеру)",
-    "Upload file" : "Отпреми фајл",
-    "Not favored" : "Ненаклоњен",
-    "An error occurred while trying to update the tags" : "Дошло је до грешке при покушају ажурирања ознака",
+    "%1$s (renamed)" : "%1$s (преименован)",
+    "renamed file" : "преименован фајл",
     "Upload (max. %s)" : "Отпремање (макс. %s)",
-    "\"{displayName}\" action executed successfully" : "Акција „{displayName}” је успешно извршена",
-    "\"{displayName}\" action failed" : "Акција „{displayName}” није успела",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Када се укључе windows компатибилна имена фајлова, постојећи фајлови се више неће моћи мењати, али њихов власник може да им промени име на исправно ново име.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Фајлови такође могу аутоматски да се мигрирају након укључивања овог подешавања, молимо вас да погледате документацију у вези са occ командом.",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "„{oldName}” је промењено на „{newName}”",
+    "Clear filter" : "Очисти филтер",
     "\"{displayName}\" failed on some elements" : "„{displayName}” није успело на неким елементима",
     "\"{displayName}\" batch action executed successfully" : "Пакетна акција „{displayName}” се успешно извршила",
-    "Submitting fields…" : "Поља се подносе…",
-    "Filter filenames…" : "Филтрирање имена фајлова…",
+    "\"{displayName}\" action failed" : "Акција „{displayName}” није успела",
+    "Submitting fields …" : "Поља се подносе…",
+    "Shared by link" : "Дељени путем везе",
+    "Shared" : "Подељено",
+    "\"{displayName}\" action executed successfully" : "Акција „{displayName}” је успешно извршена",
+    "Filter file names …" : "Филтрирање имена фајлова…",
+    "Clipboard is not available" : "Клипборд није доступан",
     "WebDAV URL copied to clipboard" : "WebDAV URL је копиран у клипборд",
     "Enable the grid view" : "Укључи приказ мреже",
     "Enable folder tree" : "Укључи стабло фолдера",
+    "WebDAV" : "ВебДАВ",
     "Copy to clipboard" : "Копирај у оставу",
     "Use this address to access your Files via WebDAV" : "Користи ову адресу да приступате Вашим фајловима преко ВебДАВа",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ако сте укључили 2FA, морате кликом овде да крерате нову лозинку апликације.",
-    "Deletion cancelled" : "Брисање је отказано",
-    "Move cancelled" : "Премештање је отказано",
-    "Cancelled move or copy of \"{filename}\"." : "Операција премештања или копирања „{filename}” је отказана.",
-    "Cancelled move or copy operation" : "Операција премештања или копирања је отказана",
-    "Open details" : "Отвори детаље",
-    "Photos and images" : "Фотографије и слике",
-    "New folder creation cancelled" : "Отказане је креирање новог фолдера",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} фолдер","{folderCount} фолдера","{folderCount} фолдера"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} фајл","{fileCount} фајла","{fileCount} фајлова"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 фајл и {folderCount} фолдер","1 фајл и {folderCount} фолдера","1 фајл и {folderCount} фолдера"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} фајл и 1 фолдер","{fileCount} фајла и 1 фолдер","{fileCount} фајлова и 1 фолдер"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} фајлова и {folderCount} фолдера",
-    "All folders" : "Сви фолдери",
-    "Personal Files" : "Лични фајлови",
-    "Text file" : "Tекстуални фајл",
-    "New text file.txt" : "Нов текстуални фајл.txt",
-    "%1$s (renamed)" : "%1$s (преименован)",
-    "renamed file" : "преименован фајл",
-    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Када се укључе windows компатибилна имена фајлова, постојећи фајлови се више неће моћи мењати, али њихов власник може да им промени име на исправно ново име.",
-    "Filter file names …" : "Филтрирање имена фајлова…",
     "Prevent warning dialogs from open or reenable them." : "Спречава да се дијалози упозорења отворе или да се поново укључе.",
     "Show a warning dialog when changing a file extension." : "Прикажи дијалог упозорења када се мења екстензија фајла.",
+    "Keyboard shortcuts" : "Пречице на тастатури",
     "Speed up your Files experience with these quick shortcuts." : "Убрзајте рад у апликацији Фајлови следећим брзим пречицама.",
     "Open the actions menu for a file" : "Отвори мени са акцијама над фајлом",
     "Rename a file" : "Промени име фајла",
@@ -472,6 +421,32 @@ OC.L10N.register(
     "Navigate to the file on the left (in grid mode)" : "Пређи на фајл са леве стране (у режиму мреже)",
     "Navigate to the file on the right (in grid mode)" : "Пређи на фајл са десне стране (у режиму мреже)",
     "Toggle the grid view" : "Укључи/искључи приказ мреже",
-    "Open the sidebar for a file" : "Отвори у бочни панел за фајл"
+    "Open the sidebar for a file" : "Отвори у бочни панел за фајл",
+    "You" : "Ви",
+    "Shared multiple times with different people" : "Дељено више пута са разним људима",
+    "Unable to change the favorite state of the file" : "Није успела измена стања омиљено за фајл",
+    "Error while loading the file data" : "Грешка при учитавању података фајла",
+    "Tags" : "Ознаке",
+    "Save as …" : "Сачувај као",
+    "Converting files …" : "Фајлови се конвертују",
+    "Converting file …" : "Фајл се конвертује",
+    "Deletion cancelled" : "Брисање је отказано",
+    "Edit locally" : "Уреди локално",
+    "Moving \"{source}\" to \"{destination}\" …" : "„{source}” се премешта у „{destination}”…",
+    "Copying \"{source}\" to \"{destination}\" …" : "„{source}” се копира у „{destination}”…",
+    "(copy)" : "(копиран)",
+    "(copy %n)" : "(копирано %n)",
+    "Move cancelled" : "Премештање је отказано",
+    "Cancelled move or copy of \"{filename}\"." : "Операција премештања или копирања „{filename}” је отказана.",
+    "Cancelled move or copy operation" : "Операција премештања или копирања је отказана",
+    "Open details" : "Отвори детаље",
+    "Photos and images" : "Фотографије и слике",
+    "New folder creation cancelled" : "Отказане је креирање новог фолдера",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Овај директоријум није доступан, проверите дневник или контактирајте администратора",
+    "All folders" : "Сви фолдери",
+    "Open file sidebar" : "Отвори бочну траку за фајл",
+    "Search everywhere …" : "Претражи свуда",
+    "Search here …" : "Претражи овде…",
+    "Preparing …" : "Припрема се синхронизација"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
